@@ -63,7 +63,7 @@ class Exceptions:
 
 class IoT1ClickDevicesServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html)
     """
 
@@ -79,7 +79,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#can_paginate)
         """
 
@@ -90,7 +90,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         Adds device(s) to your account (i.e., claim one or more devices) if and only if
         you received a claim code with the device(s).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.claim_devices_by_claim_code)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.claim_devices_by_claim_code)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#claim_devices_by_claim_code)
         """
 
@@ -99,31 +99,31 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         Given a device ID, returns a DescribeDeviceResponse object describing the
         details of the device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.describe_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.describe_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#describe_device)
         """
 
     def finalize_device_claim(
-        self, *, DeviceId: str, Tags: Mapping[str, str] = None
+        self, *, DeviceId: str, Tags: Mapping[str, str] = ...
     ) -> FinalizeDeviceClaimResponseTypeDef:
         """
         Given a device ID, finalizes the claim request for the associated device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.finalize_device_claim)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.finalize_device_claim)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#finalize_device_claim)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#generate_presigned_url)
         """
 
@@ -131,7 +131,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         """
         Given a device ID, returns the invokable methods associated with the device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.get_device_methods)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.get_device_methods)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#get_device_methods)
         """
 
@@ -139,7 +139,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         """
         Given a device ID, initiates a claim request for the associated device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.initiate_device_claim)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.initiate_device_claim)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#initiate_device_claim)
         """
 
@@ -147,14 +147,14 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         self,
         *,
         DeviceId: str,
-        DeviceMethod: "DeviceMethodTypeDef" = None,
-        DeviceMethodParameters: str = None
+        DeviceMethod: "DeviceMethodTypeDef" = ...,
+        DeviceMethodParameters: str = ...
     ) -> InvokeDeviceMethodResponseTypeDef:
         """
         Given a device ID, issues a request to invoke a named device method (with
         possible parameters).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.invoke_device_method)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.invoke_device_method)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#invoke_device_method)
         """
 
@@ -164,24 +164,24 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         DeviceId: str,
         FromTimeStamp: Union[datetime, str],
         ToTimeStamp: Union[datetime, str],
-        MaxResults: int = None,
-        NextToken: str = None
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListDeviceEventsResponseTypeDef:
         """
         Using a device ID, returns a DeviceEventsResponse object containing an array of
         events for the device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_device_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_device_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#list_device_events)
         """
 
     def list_devices(
-        self, *, DeviceType: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, DeviceType: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> ListDevicesResponseTypeDef:
         """
         Lists the 1-Click compatible devices associated with your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_devices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_devices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#list_devices)
         """
 
@@ -189,7 +189,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         """
         Lists the tags associated with the specified resource ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#list_tags_for_resource)
         """
 
@@ -197,7 +197,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         """
         Adds or updates the tags associated with the resource ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#tag_resource)
         """
 
@@ -205,7 +205,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         """
         Disassociates a device from your AWS account using its device ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.unclaim_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.unclaim_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#unclaim_device)
         """
 
@@ -214,16 +214,16 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         Using tag keys, deletes the tags (key/value pairs) associated with the specified
         resource ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#untag_resource)
         """
 
-    def update_device_state(self, *, DeviceId: str, Enabled: bool = None) -> Dict[str, Any]:
+    def update_device_state(self, *, DeviceId: str, Enabled: bool = ...) -> Dict[str, Any]:
         """
         Using a Boolean value (true or false), this operation enables or disables the
         device given a device ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.update_device_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.update_device_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#update_device_state)
         """
 
@@ -232,13 +232,13 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         self, operation_name: Literal["list_device_events"]
     ) -> ListDeviceEventsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdeviceeventspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_devices"]) -> ListDevicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdevicespaginator)
         """
